select role
from   all_roles
order by 1
